==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/mixer/v1/QuotaResultFluent.java <==
package me.snowdrop.istio.api.mixer.v1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Long;
import java.lang.Boolean;

public interface QuotaResultFluent<A extends QuotaResultFluent<A>> extends Fluent<A>{


    public Long getGrantedAmount();
    public A withGrantedAmount(Long grantedAmount);
    public Boolean hasGrantedAmount();
    public A withNewGrantedAmount(String arg1);
    public A withNewGrantedAmount(long arg1);
    
/**
 * This method has been deprecated, please use method buildReferencedAttributes instead.
 * @return The buildable object.
 */
@Deprecated public ReferencedAttributes getReferencedAttributes();
    public ReferencedAttributes buildReferencedAttributes();
    public A withReferencedAttributes(ReferencedAttributes referencedAttributes);
    public Boolean hasReferencedAttributes();
    public QuotaResultFluent.ReferencedAttributesNested<A> withNewReferencedAttributes();
    public QuotaResultFluent.ReferencedAttributesNested<A> withNewReferencedAttributesLike(ReferencedAttributes item);
    public QuotaResultFluent.ReferencedAttributesNested<A> editReferencedAttributes();
    public QuotaResultFluent.ReferencedAttributesNested<A> editOrNewReferencedAttributes();
    public QuotaResultFluent.ReferencedAttributesNested<A> editOrNewReferencedAttributesLike(ReferencedAttributes item);
    public Long getValidDuration();
    public A withValidDuration(Long validDuration);
    public Boolean hasValidDuration();
    public A withNewValidDuration(String arg1);
    public A withNewValidDuration(long arg1);

    public interface ReferencedAttributesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ReferencedAttributesFluent<QuotaResultFluent.ReferencedAttributesNested<N>>{

        
    public N and();    public N endReferencedAttributes();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/mixer/v1/QuotaResultFluent.java <==
package me.snowdrop.istio.api.mixer.v1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Boolean;

public interface QuotaResultFluent<A extends QuotaResultFluent<A>> extends Fluent<A>{


    public Integer getGrantedAmount();
    public A withGrantedAmount(Integer grantedAmount);
    public Boolean hasGrantedAmount();
    
/**
 * This method has been deprecated, please use method buildReferencedAttributes instead.
 * @return The buildable object.
 */
@Deprecated public ReferencedAttributes getReferencedAttributes();
    public ReferencedAttributes buildReferencedAttributes();
    public A withReferencedAttributes(ReferencedAttributes referencedAttributes);
    public Boolean hasReferencedAttributes();
    public QuotaResultFluent.ReferencedAttributesNested<A> withNewReferencedAttributes();
    public QuotaResultFluent.ReferencedAttributesNested<A> withNewReferencedAttributesLike(ReferencedAttributes item);
    public QuotaResultFluent.ReferencedAttributesNested<A> editReferencedAttributes();
    public QuotaResultFluent.ReferencedAttributesNested<A> editOrNewReferencedAttributes();
    public QuotaResultFluent.ReferencedAttributesNested<A> editOrNewReferencedAttributesLike(ReferencedAttributes item);
    public Integer getValidDuration();
    public A withValidDuration(Integer validDuration);
    public Boolean hasValidDuration();

    public interface ReferencedAttributesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ReferencedAttributesFluent<QuotaResultFluent.ReferencedAttributesNested<N>>{

        
    public N and();    public N endReferencedAttributes();
}


}
